import { DegreePlannerDataService } from './../../../core/service/degree-planner-data.service';
import { Component, OnInit, Inject } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material';
import { DataService } from '../../../core/data.service';
import { FormBuilder, FormGroup } from '@angular/forms';

@Component({
	selector: 'cse-notes-dialog',
	templateUrl: './notes-dialog.component.html',
	styleUrls: ['./notes-dialog.component.scss']
})

export class NotesDialogComponent implements OnInit {
	noteForm: FormGroup;
	id: number;
	note: string;
	termCode: string;
	noteData: object;

	constructor(private dataService: DataService,
				private fb: FormBuilder,
				private degreePlannerDataSvc: DegreePlannerDataService,
				private dialogRef: MatDialogRef<NotesDialogComponent>,
				@Inject(MAT_DIALOG_DATA) public data: any) {
		this.id = data.id;
		this.termCode = data.termCode;
		this.note = data.note;
		this.noteData = data;
	}

	ngOnInit() {
		this.noteForm = this.fb.group({
			id: [this.id, []],
			termCode: [this.termCode, []],
			note: [this.note, []],
		});
	}

	removeNote() {
		this.dataService.removeNote(this.degreePlannerDataSvc.getPlanId(), this.id).subscribe(() => {});
		this.dialogRef.close({ event: 'remove' });
	}

	saveNote() {
		const note = this.noteForm.value;

		if (note.id) {
			this.dataService.updateNote(this.degreePlannerDataSvc.getPlanId(), note)
			.subscribe(result => {
				this.dialogRef.close({ event: 'save'});
			});
		} else {
			this.dataService.createNote(this.degreePlannerDataSvc.getPlanId(), note)
			.subscribe(result => {
				this.dialogRef.close({ event: 'save'});
			});
		}
	}
}
